@@ -15,8 +15,7 @@
 
    You should have received a copy of the GNU Library General Public
    License along with the Gnome Library; see the file COPYING.LIB.  If not,
-   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   see <http://www.gnu.org/licenses/>.
 
    Author: Stef Walter <stef@memberwebs.com>
 */
@@ -57,11 +56,11 @@ typedef struct {
 		lock, unlock, fallback, NULL, EGG_SECURE_POOL_VER_STR };
 
 #define EGG_SECURE_DEFINE_GLIB_GLOBALS() \
-	static GStaticMutex memory_mutex = G_STATIC_MUTEX_INIT; \
+	static GMutex memory_mutex = { 0, }; \
 	static void egg_memory_lock (void) \
-		{ g_static_mutex_lock (&memory_mutex); } \
+		{ g_mutex_lock (&memory_mutex); } \
 	static void egg_memory_unlock (void) \
-		{ g_static_mutex_unlock (&memory_mutex); } \
+		{ g_mutex_unlock (&memory_mutex); } \
 	EGG_SECURE_DEFINE_GLOBALS (egg_memory_lock, egg_memory_unlock, g_realloc);
 
 extern egg_secure_glob EGG_SECURE_GLOBALS;
