@@ -20,7 +20,7 @@
  */
 
 #if !defined (__GCR_INSIDE_HEADER__) && !defined (GCR_COMPILATION)
-#error "Only <gcr/gcr.h> or <gcr/gcr-base.h> can be included directly."
+#error "Only <gcr/gcr.h> can be included directly."
 #endif
 
 #ifndef GCR_CERTIFICATE_EXTENSIONS_H
